@@ -12,5 +12,5 @@ def ofTimestamp(t):
 
 def plusMinutes(givenDateTime, minutes=None, deltaInMinutes=None) :
     if ObjectHelper.isNotNone(minutes) :
-        deltaInMinutes = timeDelta(seconds=minutes*60)
+        deltaInMinutes = DateTimeHelper.timeDelta(seconds=minutes*60)
     return givenDateTime + deltaInMinutes
